( cd usr/share/icons/hicolor/32x32/apps ; rm -rf gftp.png )
( cd usr/share/icons/hicolor/32x32/apps ; ln -sf /usr/share/gftp/gftp-32x32.png gftp.png )
( cd usr/share/icons/hicolor/24x24/apps ; rm -rf gftp.png )
( cd usr/share/icons/hicolor/24x24/apps ; ln -sf /usr/share/gftp/gftp-24x24.png gftp.png )
( cd usr/share/icons/hicolor/48x48/apps ; rm -rf gftp.png )
( cd usr/share/icons/hicolor/48x48/apps ; ln -sf /usr/share/gftp/gftp-48x48.png gftp.png )
( cd usr/share/icons/hicolor/scalable/apps ; rm -rf gftp.svg )
( cd usr/share/icons/hicolor/scalable/apps ; ln -sf /usr/share/gftp/gftp-scalable.svg gftp.svg )
( cd usr/share/icons/hicolor/16x16/apps ; rm -rf gftp.png )
( cd usr/share/icons/hicolor/16x16/apps ; ln -sf /usr/share/gftp/gftp-16x16.png gftp.png )
( cd usr/share/icons/hicolor/22x22/apps ; rm -rf gftp.png )
( cd usr/share/icons/hicolor/22x22/apps ; ln -sf /usr/share/gftp/gftp-22x22.png gftp.png )
